@@ -44,7 +44,14 @@ func NewGitLab(ctx *context.Context, token string) (Client, error) {
 
 		options = append(options, gitlab.WithBaseURL(apiURL))
 	}
-	client, err := gitlab.NewClient(token, options...)
+
+	var client *gitlab.Client
+	var err error
+	if ctx.Config.GitLabURLs.UseJobToken {
+		client, err = gitlab.NewJobClient(token, options...)
+	} else {
+		client, err = gitlab.NewClient(token, options...)
+	}
 	if err != nil {
 		return &gitlabClient{}, err
 	}
