@@ -358,7 +358,7 @@ func TestRunPipe_TargetTemplateError(t *testing.T) {
 				Name: "production",
 				Mode: "binary",
 				// This template is not correct and should fail
-				Target:   "http://storage.company.com/example-repo-local/{{ .ProjectName /{{ .Version }}/",
+				Target:   "http://storage.company.com/example-repo-local/{{.Name}",
 				Username: "deployuser",
 			},
 		},
@@ -378,7 +378,7 @@ func TestRunPipe_TargetTemplateError(t *testing.T) {
 	})
 
 	require.NoError(t, Pipe{}.Default(ctx))
-	require.EqualError(t, Pipe{}.Publish(ctx), `artifactory: error while building the target url: template: tmpl:1: unexpected "/" in operand`)
+	testlib.RequireTemplateError(t, Pipe{}.Publish(ctx))
 }
 
 func TestRunPipe_BadCredentials(t *testing.T) {
